@@ -12,11 +12,12 @@
 #' @param d18O_H2O_VSMOW Water d18O value expressed on the VSMOW scale (‰).
 #' @param D17O_H2O D17O value of ambient water calculated using
 #'   a lambda of `0.528`. Default `0`.
-#' @param min Mineralogy. Options are `"calcite"` (default), `"aragonite"`,
-#'   `apatite`, `siderite`, and `"dolomite"`.
+#' @param min Mineralogy. Options are `"calcite"` (default) and `"aragonite"`.
 #' @param eq18 Equation used to calculate the 18O/16O fractionation factor
-#'   between calcite and water. Options are like in [a18_c_H2O()].
+#'   between carbonate and water. Options are like in [a18_c_H2O()].
 #'   Default `"Daeron19"`.
+#' @param eq17 Equation used to calculate the 17O/16O fractionation factor
+#'   between carbonate and water. Options are `"Wostbrock20"` (default) and `"GZ19"`.
 #' @param lambda Triple oxygen isotope reference slope. Default `0.528`.
 #'
 #' @return
@@ -35,16 +36,27 @@
 #' \deqn{\Delta^{17}O_{CaCO3,VSMOW} = \delta'^{17}O_{CaCO3,VSMOW} -
 #' \lambda \times \delta'^{18}O_{CaCO3,VSMOW} }
 #'
-#' **NOTE:** Due to a lack of experimental and theoretical data,
-#' the theta values for all carbonate mineralogies - except aragonite -
-#' are calculated with the calcite equitation from Guo & Zhou (2019):
+#' `"Wostbrock20"`: Wostbrock et al. (2020):
+#'
+#' \deqn{\theta_{aragonite/water} = \frac{-1.53}{T} + 0.5305}
+#'
+#' \deqn{\theta_{calcite/water} = \frac{-1.39}{T} + 0.5305}
+#'
+#' `"GZ19"`: Guo and Zhou (2019):
 #'
 #' \deqn{\theta_{aragonite/water} = \frac{78.1173}{T^{2}} - \frac{1.5152}{T} + 0.5299}
 #'
 #' \deqn{\theta_{calcite/water} = \frac{59.1047}{T^{2}} - \frac{1.4089}{T} + 0.5297}
 #'
 #' @references
-#' Guo, W., & Zhou, C. (2019).
+#' Wostbrock, J.A.G., Brand, U., Coplen, T.B., Swart, P.K.,
+#' Carlson, S.J., Brearley, A.J., and Sharp, Z.D. (2020).
+#' Calibration of carbonate-water triple oxygen isotope fractionation:
+#' Seeing through diagenesis in ancient carbonates.
+#' Geochimica et Cosmochimica Acta, 288, 369-388.
+#' \doi{10.1016/j.gca.2020.07.045}
+#'
+#' Guo, W., and Zhou, C. (2019).
 #' Triple oxygen isotope fractionation in the DIC-H2O-CO2 system:
 #' A numerical framework and its implications.
 #' Geochimica et Cosmochimica Acta, 246, 541-564.
@@ -59,29 +71,39 @@
 #'
 #' @export
 
-d17O_c = function(temp, d18O_H2O_VSMOW, D17O_H2O = 0, min = "calcite", eq18 = "Daeron19", lambda = 0.528) {
+d17O_c = function(temp, d18O_H2O_VSMOW, D17O_H2O = 0, min = "calcite", eq17 = "Wostbrock20", eq18 = "Daeron19", lambda = 0.528) {
 
   TinK = temp + 273.15
 
-  if (min == "aragonite") {
-    # Guo and Zhou (2019)
-    theta = 78.1173 / TinK ^ 2 - 1.5152 / TinK + 0.5299
+if (min == "aragonite") {
+    if (eq17 == "GZ19")  {
+      # Guo and Zhou (2019)
+      theta = 78.1173 / TinK ^ 2 - 1.5152 / TinK + 0.5299
+    } else if (eq17 == "Wostbrock20") {
+      # Wostbrock et al. (2020)
+      theta = -1.53 / TinK + 0.5305
+    } else {
+      stop("Invalid input for eq17. Options for aragonite are GZ19 and Wostbrock20.")
+    }
+  } else if (min == "calcite") {
+    if (eq17 == "GZ19")  {
+      # Guo and Zhou (2019)
+      theta = 59.1047 / TinK ^ 2 - 1.4089 / TinK + 0.5297
+    } else if (eq17 == "Wostbrock20") {
+      # Wostbrock et al. (2020)
+      theta = -1.39 / TinK + 0.5305
+    } else {
+      stop("Invalid input for eq17. Options for calcite are GZ19 and Wostbrock20.")
+    }
   } else {
-    # Guo and Zhou (2019)
-    theta = 59.1047 / TinK ^ 2 - 1.4089 / TinK + 0.5297
+    stop("Invalid input for min. Options are calcite and aragonite.")
   }
 
   a18_c_H2O = isogeochem::a18_c_H2O(temp = temp, min = min, eq = eq18)
   a17_c_H2O  = a18_c_H2O ^ theta
-
   d18O_c   = d18O_c(temp, d18O_H2O_VSMOW, min = min, eq18)
 
-  # calculating the d17O prime value of ambient water
-  if (methods::is(D17O_H2O, "numeric") && is.finite(D17O_H2O)) {
-    d17Ow_p = D17O_H2O + lambda * prime(d18O_H2O_VSMOW)
-  } else {
-    stop("Invalid input for D17O_H2O")
-  }
+  d17Ow_p = D17O_H2O + lambda * prime(d18O_H2O_VSMOW)
 
   d17O_c = (unprime(d17Ow_p) + 1000) * a17_c_H2O - 1000
   D17O_c  = prime(d17O_c) - lambda * prime(d18O_c)
